@@ -101,3 +101,9 @@ def print_time(txt='', st=0):
     m, s = divmod(seconds, 60)
     h, m = divmod(m, 60)
     print(txt, '{:1d}:{:02d}:{:05.2f}'.format(int(h), int(m), s))
+
+
+class Namespace():
+    ### Defines empty namespace ###
+    def __init__(self, **kwargs):
+        self.__dict__.update(kwargs)
